@@ -1226,7 +1226,8 @@
 
     const isNavigatorDefined = typeof navigator !== "undefined";
     const userAgent = isNavigatorDefined
-        ? navigator.userAgentData
+        ? navigator.userAgentData &&
+          Array.isArray(navigator.userAgentData.brands)
             ? navigator.userAgentData.brands
                   .map(
                       (brand) => `${brand.brand.toLowerCase()} ${brand.version}`
@@ -1235,7 +1236,8 @@
             : navigator.userAgent.toLowerCase()
         : "some useragent";
     const platform = isNavigatorDefined
-        ? navigator.userAgentData
+        ? navigator.userAgentData &&
+          typeof navigator.userAgentData.platform === "string"
             ? navigator.userAgentData.platform.toLowerCase()
             : navigator.platform.toLowerCase()
         : "some platform";
